datablock AudioProfile(KatarDrawSound)
{
   filename    = "./Resources/drawkatar.wav";
   description = AudioClosest3d;
   preload = true;
};
datablock AudioProfile(KatarHitSound)
{
   filename    = "./Resources/katarimpact.wav";
   description = AudioClosest3d;
   preload = true;
};

datablock ParticleData(KatarExplosionParticle)
{
   dragCoefficient      = 2;
   gravityCoefficient   = 1.0;
   inheritedVelFactor   = 0.2;
   constantAcceleration = 0.0;
   spinRandomMin = -90;
   spinRandomMax = 90;
   lifetimeMS           = 450;
   lifetimeVarianceMS   = 300;
   textureName          = "base/data/particles/chunk";
   colors[0]     = "1 1 1 0.9";
   colors[1]     = "1 1 1 0.2";
   sizes[0]      = 0.1;
   sizes[1]      = 0.1;
};

datablock ParticleEmitterData(KatarExplosionEmitter)
{
   ejectionPeriodMS = 7;
   periodVarianceMS = 0;
   ejectionVelocity = 8;
   velocityVariance = 4.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 60;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "KatarExplosionParticle";

   uiName = "";
};

datablock ExplosionData(KatarExplosion)
{
   lifeTimeMS = 500;
   soundProfile = KatarHitSound;
   particleEmitter = KatarExplosionEmitter;
   particleDensity = 30;
   particleRadius = 0.2;
   faceViewer     = true;
   explosionScale = "0.2 0.2 0.2";
   shakeCamera = true;
   camShakeFreq = "8.0 8.0 8.0";
   camShakeAmp = "1.0 1.0 1.0";
   camShakeDuration = 0.2;
   camShakeRadius = 4.0;
   lightStartRadius = 0;
   lightEndRadius = 0;
   lightStartColor = "00.0 0.2 0.6";
   lightEndColor = "0 0 0";
};

AddDamageType("Katar",   '<bitmap:Add-Ons/Weapon_DefaultishWeapons/Resources/CI_Katar> %1',    '%2 <bitmap:Add-Ons/Weapon_DefaultishWeapons/Resources/CI_Katar> %1',0.5,1);

datablock ProjectileData(KatarProjectile)
{
   directDamage        = 20;
   directDamageType  = $DamageType::Katar;
   radiusDamageType  = $DamageType::Katar;
   explosion           = KatarExplosion;
   muzzleVelocity      = 50;
   velInheritFactor    = 1;
   armingDelay         = 0;
   lifetime            = 68;
   fadeDelay           = 70;
   bounceElasticity    = 0;
   bounceFriction      = 0;
   isBallistic         = false;
   gravityMod = 0.0;

   hasLight    = false;
   lightRadius = 3.0;
   lightColor  = "0 0 0.5";

   uiName = "";
};

datablock ItemData(KatarItem)
{
	category = "Weapon";
	className = "Weapon";
	shapeFile = "./Resources/Katar.dts";
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;
	rotation = "0 0 180";
	uiName = "Katar";
	iconName = "./Resources/Icon_Katar";
	doColorShift = true;
	colorShiftColor = "0.78 0.63 0.15 1.000";
	image = KatarImage;
	canDrop = true;
};

datablock ShapeBaseImageData(KatarImage)
{
   shapeFile = "./Resources/Katar.dts";
   emap = true;
   mountPoint = 0;
   offset = "0 0 0";
   correctMuzzleVector = false;
   eyeOffset = "0 0 0";
   className = "WeaponImage";
   item = KatarItem;
   ammo = " ";
   projectile = KatarProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = true;
   doRetraction = false;
   //raise your arm up or not
   armReady = true;
   doColorShift = true;
   colorShiftColor = "0.78 0.63 0.15 1.000";

	stateName[0]                     = "Activate";
	stateTimeoutValue[0]             = 0.5;
	stateTransitionOnTimeout[0]      = "Ready";
	stateSound[0]                    = KatarDrawSound;

	stateName[1]                     = "Ready";
	stateTransitionOnTriggerDown[1]  = "PreFire";
	stateAllowImageChange[1]         = true;

	stateName[2]			= "PreFire";
	stateScript[2]                  = "onPreFire";
	stateAllowImageChange[2]        = true;
	stateTimeoutValue[2]            = 0.1;
	stateTransitionOnTimeout[2]     = "Fire";

	stateName[3]                    = "Fire";
	stateTransitionOnTimeout[3]     = "Fire2";
	stateTimeoutValue[3]            = 0.1;
	stateFire[3]                    = true;
	stateAllowImageChange[3]        = true;
	stateSequence[3]                = "Fire";
	stateScript[3]                  = "onFire";
	stateWaitForTimeout[3]		= true;

	stateName[4]                    = "Fire2";
	stateScript[4]                  = "onFire2";
	stateTransitionOnTimeout[4]     = "CheckFire";
	stateAllowImageChange[4]        = true;
	stateTimeoutValue[4]            = 0.5;

	stateName[5]			= "CheckFire";
	stateTransitionOnTriggerUp[5]	= "StopFire";
	stateTransitionOnTriggerDown[5]	= "Fire";

	
	stateName[6]                    = "StopFire";
	stateTransitionOnTimeout[6]     = "Ready";
	stateTimeoutValue[6]            = 0.2;
	stateAllowImageChange[6]        = false;
	stateWaitForTimeout[6]		= true;
	stateSequence[6]                = "StopFire";
	stateScript[6]                  = "onStopFire";


};

function KatarImage::onFire(%this, %obj, %slot)
{
	if(%obj.getDamagePercent() < 1.0)
		%obj.playThread(2, ShiftLeft);
	Parent::onFire(%this,%obj,%slot);	
}

function KatarImage::onFire2(%this,%obj,%slot)
{
	if(%obj.getDamagePercent() < 1.0)
		%obj.playThread(2, ShiftAway);
	Parent::onFire(%this,%obj,%slot);	
}

function KatarImage::onStopFire(%this, %obj, %slot)
{	
	%obj.playthread(2, root);
}